CHANGELOG
---------

0.1.18 (25th November 2015)

- Add initial support for Amazon ElasticSearch
- Minor output improvements and refactoring

0.1.17 (22nd November 2015)

- Allow use of ls instead of list for the various services
- Only transfer between local and S3 if files differ
